from datetime import datetime
from typing import Iterable, List, Optional, TYPE_CHECKING, Union, Callable


from .text import Text, TextType

if TYPE_CHECKING:
    from .console import Console, ConsoleRenderable, RenderableType
    from .table import Table

FormatTimeCallable = Callable[[datetime], Text]


class LogRender:
    def __init__(
        self,
        show_time: bool = True,
        show_level: bool = False,
        show_path: bool = True,
        time_format: Union[str, FormatTimeCallable] = "[%x %X]",
        omit_repeated_times: bool = True,
        level_width: Optional[int] = 8,
    ) -> None:
        self.show_time = show_time
        self.show_level = show_level
        self.show_path = show_path
        self.time_format = time_format
        self.omit_repeated_times = omit_repeated_times
        self.level_width = level_width
        self._last_time: Optional[Text] = None

    def __call__(
        self,
        console: "Console",
        renderables: Iterable["ConsoleRenderable"],
        log_time: Optional[datetime] = None,
        time_format: Optional[Union[str, FormatTimeCallable]] = None,
        level: TextType = "",
        path: Optional[str] = None,
        line_no: Optional[int] = None,
        link_path: Optional[str] = None,
    ) -> "Table":
        from .containers import Renderables
        from .table import Table

        output = Table.grid(padding=(0, 1))
        output.expand = True
        if self.show_time:
            output.add_column(style="log.time")
        if self.show_level:
            output.add_column(style="log.level", width=self.level_width)
        output.add_column(ratio=1, style="log.message", overflow="fold")
        if self.show_path and path:
            output.add_column(style="log.path")
        row: List["RenderableType"] = []
        if self.show_time:
            log_time = log_time or console.get_datetime()
            time_format = time_format or self.time_format
            if callable(time_format):
                log_time_display = time_format(log_time)
            else:
                log_time_display = Text(log_time.strftime(time_format))
            if log_time_display == self._last_time and self.omit_repeated_times:
                row.append(Text(" " * len(log_time_display)))
            else:
                row.append(log_time_display)
                self._last_time = log_time_display
        if self.show_level:
            row.append(level)

        row.append(Renderables(renderables))
        if self.show_path and path:
            path_text = Text()
            path_text.append(
                path, style=f"link file://{link_path}" if link_path else ""
            )
            if line_no:
                path_text.append(":")
                path_text.append(
                    f"{line_no}",
                    style=f"link file://{link_path}#{line_no}" if link_path else "",
                )
            row.append(path_text)

        output.add_row(*row)
        return output


if __name__ == "__main__":  # pragma: no cover
    from aylak.rich.console import Console

    c = Console()
    c.print("[on blue]Hello", justify="right")
    c.log("[on blue]hello", justify="right")



import os
import platform

from aylak.rich import inspect
from aylak.rich.console import Console, get_windows_console_features
from aylak.rich.panel import Panel
from aylak.rich.pretty import Pretty


def report() -> None:  # pragma: no cover
    """Print a report to the terminal with debugging information"""
    console = Console()
    inspect(console)
    features = get_windows_console_features()
    inspect(features)

    env_names = (
        "TERM",
        "COLORTERM",
        "CLICOLOR",
        "NO_COLOR",
        "TERM_PROGRAM",
        "COLUMNS",
        "LINES",
        "JUPYTER_COLUMNS",
        "JUPYTER_LINES",
        "JPY_PARENT_PID",
        "VSCODE_VERBOSE_LOGGING",
    )
    env = {name: os.getenv(name) for name in env_names}
    console.print(Panel.fit((Pretty(env)), title="[b]Environment Variables"))

    console.print(f'platform="{platform.system()}"')


if __name__ == "__main__":  # pragma: no cover
    report()



'''from PIL import Image, ImageEnhance


class ImageTools:
    def __init__(self):
        pass

    def convert(
        self, image_path: str, output_format: str = "png"
    ):  # output_format: str="png"
        """
        Bir görüntüyü belirtilen biçime dönüştürür.

        :param image_path: Görüntü path'ı.
        :param output_format: Dönüştürmek için biçim.
        :return: Dönüştürülmüş görüntünün path'ı.
        """
        supported_formats = ["png", "jpeg", "jpg", "webp", "tiff", "bmp", "gif", "ico"]
        try:
            if (
                output_format not in supported_formats
                or image_path.split(".")[-1] not in supported_formats
            ):
                raise Exception(
                    f"Desteklenmeyen biçim. Desteklenen biçimler: {supported_formats}"
                )
            extension = image_path.split(".")[-1]
            if extension == output_format:
                return image_path
            image = Image.open(image_path)
            image.save(
                f"{image_path.replace(extension, '')}.{output_format}",
                output_format.upper(),
            )
            return f"{image_path.replace(extension, '')}.{output_format}"
        except Exception as e:
            print(f"Error: {e}")
            return None

    def resize(self, image_path: str, width: int, height: int):
        """
        Bir görüntünün boyutunu belirtilen boyuta ayarlar.

        :param image_path: Görüntü path'ı.
        :param width: Yeni genişlik.
        :param height: Yeni yükseklik.
        :return: Boyutlandırılmış görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = image.resize((width, height))
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def crop(self, image_path: str, x1: int, y1: int, x2: int, y2: int):
        """
        Bir görüntünün belirtilen koordinatlarda kırpılmasını sağlar.

        :param image_path: Görüntü path'ı.
        :param x1: X1 koordinatı.
        :param y1: Y1 koordinatı.
        :param x2: X2 koordinatı.
        :param y2: Y2 koordinatı.
        :return: Kırpılmış görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = image.crop((x1, y1, x2, y2))
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def rotate(self, image_path: str, angle: int):
        """
        Bir görüntünün açısını belirtilen açıya döndürür.

        :param image_path: Görüntü path'ı.
        :param angle: Döndürme açısı.
        :return: Döndürülmüş görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = image.rotate(angle)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def flip(self, image_path: str, direction: str = "horizontal"):
        """
        Bir görüntünün yönünü belirtilen yönüne çevirir.

        :param image_path: Görüntü path'ı.
        :param direction: Yön. Varsayılan: "horizontal" (yatay) ya da "vertical" (dikey)
        :return: Çevrilmiş görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            if direction == "horizontal":
                image = image.transpose(Image.FLIP_LEFT_RIGHT)
            elif direction == "vertical":
                image = image.transpose(Image.FLIP_TOP_BOTTOM)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def mirror(self, image_path: str, direction: str = "horizontal"):
        """
        Bir görüntünün yönünü belirtilen yönüne çevirir.

        :param image_path: Görüntü path'ı.
        :param direction: Yön. Varsayılan: "horizontal" (yatay) ya da "vertical" (dikey)
        :return: Çevrilmiş görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            if direction == "horizontal":
                image = image.transpose(Image.FLIP_LEFT_RIGHT)
            elif direction == "vertical":
                image = image.transpose(Image.FLIP_TOP_BOTTOM)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def grayscale(self, image_path: str):
        """
        Bir görüntünün renklerini griye çevirir.

        :param image_path: Görüntü path'ı.
        :return: Gri görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = image.convert("L")
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def invert(self, image_path: str):
        """
        Bir görüntünün renklerini tersine çevirir.

        :param image_path: Görüntü path'ı.
        :return: Ters görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = Image.eval(image, lambda x: 255 - x)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def brightness(self, image_path: str, value: int):
        """
        Bir görüntünün parlaklığını belirtilen değere ayarlar.

        :param image_path: Görüntü path'ı.
        :param value: Parlaklık değeri.
        :return: Parlak görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = ImageEnhance.Brightness(image).enhance(value)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def contrast(self, image_path: str, value: int):
        """
        Bir görüntünün kontrastını belirtilen değere ayarlar.

        :param image_path: Görüntü path'ı.
        :param value: Kontrast değeri.
        :return: Kontrastlı görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = ImageEnhance.Contrast(image).enhance(value)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def color(self, image_path: str, value: int):
        """
        Bir görüntünün renklerini belirtilen değere ayarlar.

        :param image_path: Görüntü path'ı.
        :param value: Renk değeri.
        :return: Renkli görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = ImageEnhance.Color(image).enhance(value)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None

    def sharpness(self, image_path: str, value: int):
        """
        Bir görüntünün keskinliğini belirtilen değere ayarlar.

        :param image_path: Görüntü path'ı.
        :param value: Keskinlik değeri.
        :return: Keskin görüntünün path'ı.
        """
        try:
            image = Image.open(image_path)
            image = ImageEnhance.Sharpness(image).enhance(value)
            image.save(image_path)
            return image_path
        except Exception as e:
            print(f"Error: {e}")
            return None
'''



from ..rpc_errors import RPCError


# * Invalids
class InvalidRGBColorError(RPCError):
    """Raised when an invalid RGB color is provided."""

    CODE = 400
    NAME = "InvalidRGBColorError"
    MESSAGE = "Invalid RGB color: {value}"


class InvalidHEXColorError(RPCError):
    """Raised when an invalid HEX color is provided."""

    CODE = 400
    NAME = "InvalidHEXColorError"
    MESSAGE = "Invalid HEX color: {value}"


class InvalidColorError(RPCError):
    """Raised when an invalid color is provided."""

    CODE = 400
    NAME = "InvalidColorError"
    MESSAGE = "Invalid color: {value}"


class InvalidColorCodeError(RPCError):
    """Raised when an invalid color code is provided."""

    CODE = 400
    NAME = "InvalidColorCodeError"
    MESSAGE = "Invalid color code: {value}"


class InvalidColorNameError(RPCError):
    """Raised when an invalid color name is provided."""

    CODE = 400
    NAME = "InvalidColorNameError"
    MESSAGE = "Invalid color name: {value}"


class InvalidColorTypeError(RPCError):
    """Raised when an invalid color type is provided."""

    CODE = 400
    NAME = "InvalidColorTypeError"
    MESSAGE = "Invalid color type: {value}"


class InvalidColorValueError(RPCError):
    """Raised when an invalid color value is provided."""

    CODE = 400
    NAME = "InvalidColorValueError"
    MESSAGE = "Invalid color value: {value}"


class InvalidColorFormatError(RPCError):
    """Raised when an invalid color format is provided."""

    CODE = 400
    NAME = "InvalidColorFormatError"
    MESSAGE = "Invalid color format: {value}"


# * Not Founds
class ColorNotFoundError(RPCError):
    """Raised when a color is not found."""

    CODE = 404
    NAME = "ColorNotFoundError"
    MESSAGE = "Color not found: {value}"


# * Exists
class ColorAlreadyExistsError(RPCError):
    """Raised when a color already exists."""

    CODE = 400
    NAME = "ColorAlreadyExistsError"
    MESSAGE = "Color already exists: {value}"


class ColorCodeAlreadyExistsError(RPCError):
    """Raised when a color code already exists."""

    CODE = 400
    NAME = "ColorCodeAlreadyExistsError"
    MESSAGE = "Color code already exists: {value}"


class ColorNameAlreadyExistsError(RPCError):
    """Raised when a color name already exists."""

    CODE = 400
    NAME = "ColorNameAlreadyExistsError"
    MESSAGE = "Color name already exists: {value}"


# * Print JSON Errors
class PrintJSONError(RPCError):
    """Raised when a print JSON error occurs."""

    CODE = 400
    NAME = "PrintJSONError"
    MESSAGE = "Print JSON error: {value}"


class PrintJSONIndentError(RPCError):
    """Raised when a print JSON indent error occurs."""

    CODE = 400
    NAME = "PrintJSONIndentError"
    MESSAGE = "Print JSON indent error: {value}"


class PrintJSONEnsureAsciiError(RPCError):
    """Raised when a print JSON ensure ascii error occurs."""

    CODE = 400
    NAME = "PrintJSONEnsureAsciiError"
    MESSAGE = "Print JSON ensure ascii error: {value}"


class PrintJSONSortKeysError(RPCError):
    """Raised when a print JSON sort keys error occurs."""

    CODE = 400
    NAME = "PrintJSONSortKeysError"
    MESSAGE = "Print JSON sort keys error: {value}"


class PrintJSONSkipKeysError(RPCError):
    """Raised when a print JSON skip keys error occurs."""

    CODE = 400
    NAME = "PrintJSONSkipKeysError"
    MESSAGE = "Print JSON skip keys error: {value}"


class PrintJSONKeySeparatorError(RPCError):
    """Raised when a print JSON key separator error occurs."""

    CODE = 400
    NAME = "PrintJSONKeySeparatorError"
    MESSAGE = "Print JSON key separator error: {value}"


class PrintJSONNotSTRError(RPCError):
    """Raised when a print JSON not STR error occurs."""

    CODE = 400
    NAME = "PrintJSONNotSTRError"
    MESSAGE = "Print JSON not STR error: {value}"




from .utils.converters import convert_color_to_ansi, hex_to_rgb
from .hex import HEXRenkler
from .rgb import RGBRenkler
from ._print import print

__all__ = [
    "HEXRenkler",
    "RGBRenkler",
    "convert_color_to_ansi",
    "hex_to_rgb",
    "print",
]

class RGBRenkler:
    bordo = convert_color_to_ansi((128, 0, 0))                                  # '#800000'
    koyu_kirmizi = convert_color_to_ansi((139, 0, 0))                           # '#8B0000'
    kahverengi = convert_color_to_ansi((165, 42, 42))                           # '#A52A2A'
    ates_tuglasi = convert_color_to_ansi((178, 34, 34))                         # '#B22222'
    kizil = convert_color_to_ansi((220, 20, 60))                                # '#DC143C'
    kirmizi = convert_color_to_ansi((255, 0, 0))                                # '#FF0000'
    domates = convert_color_to_ansi((255, 99, 71))                              # '#FF6347'
    mercan = convert_color_to_ansi((255, 127, 80))                              # '#FF7F50'
    hint_kirmizisi = convert_color_to_ansi((205, 92, 92))                       # '#CD5C5C'
    hafif_mercan = convert_color_to_ansi((240, 128, 128))                       # '#F08080'
    koyu_somon = convert_color_to_ansi((233, 150, 122))                         # '#E9967A'
    somon = convert_color_to_ansi((250, 128, 114))                              # '#FA8072'
    hafif_somon = convert_color_to_ansi((255, 160, 122))                        # '#FFA07A'
    turuncu_kirmizi = convert_color_to_ansi((255, 69, 0))                       # '#FF4500'
    koyu_turuncu = convert_color_to_ansi((255, 140, 0))                         # '#FF8C00'
    portakal = convert_color_to_ansi((255, 165, 0))                             # '#FFA500'
    altin = convert_color_to_ansi((255, 215, 0))                                # '#FFD700'
    koyu_altin_cubuk = convert_color_to_ansi((184, 134, 11))                    # '#B8860B'
    altin_cubuk = convert_color_to_ansi((218, 165, 32))                         # '#DAA520'
    soluk_altin_cubuk = convert_color_to_ansi((238, 232, 170))                  # '#EEE8AA'
    koyu_haki = convert_color_to_ansi((189, 183, 107))                          # '#BDB76B'
    haki = convert_color_to_ansi((240, 230, 140))                               # '#F0E68C'
    zeytin = convert_color_to_ansi((128, 128, 0))                               # '#808000'
    sari = convert_color_to_ansi((255, 255, 0))                                 # '#FFFF00'
    sari_yesil = convert_color_to_ansi((154, 205, 50))                          # '#9ACD32'
    koyu_zeytin_yesili = convert_color_to_ansi((85, 107, 47))                   # '#556B2F'
    zeytin_yesili = convert_color_to_ansi((107, 142, 35))                       # '#6B8E23'
    yesil_cimen = convert_color_to_ansi((124, 252, 0))                          # '#7CFC00'
    grafigin_yeniden_kullanimi = convert_color_to_ansi((127, 255, 0))           # '#7FFF00'
    yesil_sari = convert_color_to_ansi((173, 255, 47))                          # '#ADFF2F'
    koyu_yesil = convert_color_to_ansi((0, 100, 0))                             # '#006400'
    yesil = convert_color_to_ansi((0, 128, 0))                                  # '#008000'
    orman_yesili = convert_color_to_ansi((34, 139, 34))                         # '#228B22'
    misket_limonu = convert_color_to_ansi((0, 255, 0))                          # '#00FF00'
    limon_yesili = convert_color_to_ansi((50, 205, 50))                         # '#32CD32'
    acik_yesil = convert_color_to_ansi((144, 238, 144))                         # '#90EE90'
    soluk_yesil = convert_color_to_ansi((152, 251, 152))                        # '#98FB98'
    koyu_deniz_yesili = convert_color_to_ansi((143, 188, 143))                  # '#8FBC8F'
    orta_bahar_yesili = convert_color_to_ansi((0, 250, 154))                    # '#00FA9A'
    ilkbahar_yesili = convert_color_to_ansi((0, 255, 127))                      # '#00FF7F'
    deniz_yesili = convert_color_to_ansi((46, 139, 87))                         # '#2E8B57'
    orta_su_denizi = convert_color_to_ansi((102, 205, 170))                     # '#66CDAA'
    orta_deniz_yesili = convert_color_to_ansi((60, 179, 113))                   # '#3CB371'
    acik_deniz_yesili = convert_color_to_ansi((32, 178, 170))                   # '#20B2AA'
    koyu_arduvaz_grisi = convert_color_to_ansi((47, 79, 79))                    # '#2F4F4F'
    camurcun = convert_color_to_ansi((0, 128, 128))                             # '#008080'
    koyu_camgobegi = convert_color_to_ansi((0, 139, 139))                       # '#008B8B'
    su = convert_color_to_ansi((0, 255, 255))                                   # '#00FFFF'
    camgobegi = convert_color_to_ansi((0, 255, 255))                            # '#00FFFF'
    acik_cam_gobegi = convert_color_to_ansi((224, 255, 255))                    # '#E0FFFF'
    koyu_turkuaz = convert_color_to_ansi((0, 206, 209))                         # '#00CED1'
    turkuaz = convert_color_to_ansi((64, 224, 208))                             # '#40E0D0'
    orta_turkuaz = convert_color_to_ansi((72, 209, 204))                        # '#48D1CC'
    soluk_turkuaz = convert_color_to_ansi((175, 238, 238))                      # '#AFEEEE'
    aqua_marine = convert_color_to_ansi((127, 255, 212))                        # '#7FFFD4'
    toz_mavi = convert_color_to_ansi((176, 224, 230))                           # '#B0E0E6'
    harbiyeli_mavisi = convert_color_to_ansi((95, 158, 160))                    # '#5F9EA0'
    celik_mavisi = convert_color_to_ansi((70, 130, 180))                        # '#4682B4'
    misir_cicegi_mavisi = convert_color_to_ansi((100, 149, 237))                # '#6495ED'
    derin_gok_mavisi = convert_color_to_ansi((0, 191, 255))                     # '#00BFFF'
    kacak_mavi = convert_color_to_ansi((30, 144, 255))                          # '#1E90FF'
    acik_mavi = convert_color_to_ansi((173, 216, 230))                          # '#ADD8E6'
    gokyuzu_mavi = convert_color_to_ansi((135, 206, 235))                       # '#87CEEB'
    acik_gok_mavisi = convert_color_to_ansi((135, 206, 250))                    # '#87CEFA'
    gece_yarisi_mavisi = convert_color_to_ansi((25, 25, 112))                   # '#191970'
    donanma = convert_color_to_ansi((0, 0, 128))                                # '#000080'
    koyu_mavi = convert_color_to_ansi((0, 0, 139))                              # '#00008B'
    orta_mavi = convert_color_to_ansi((0, 0, 205))                              # '#0000CD'
    mavi = convert_color_to_ansi((0, 0, 255))                                   # '#0000FF'
    kraliyet_mavisi = convert_color_to_ansi((65, 105, 225))                     # '#4169E1'
    mavi_menekse = convert_color_to_ansi((138, 43, 226))                        # '#8A2BE2'
    civit = convert_color_to_ansi((75, 0, 130))                                 # '#4B0082'
    koyu_barut_mavisi = convert_color_to_ansi((72, 61, 139))                    # '#483D8B'
    barut_mavisi = convert_color_to_ansi((106, 90, 205))                        # '#6A5ACD'
    orta_barut_mavisi = convert_color_to_ansi((123, 104, 238))                  # '#7B68EE'
    orta_mor = convert_color_to_ansi((147, 112, 219))                           # '#9370DB'
    koyu_macenta = convert_color_to_ansi((139, 0, 139))                         # '#8B008B'
    koyu_mor = convert_color_to_ansi((148, 0, 211))                             # '#9400D3'
    koyu_orkide = convert_color_to_ansi((153, 50, 204))                         # '#9932CC'
    orta_boy_orkide = convert_color_to_ansi((186, 85, 211))                     # '#BA55D3'
    mor = convert_color_to_ansi((128, 0, 128))                                  # '#800080'
    devedikeni = convert_color_to_ansi((216, 191, 216))                         # '#D8BFD8'
    erik = convert_color_to_ansi((221, 160, 221))                               # '#DDA0DD'
    menekse = convert_color_to_ansi((238, 130, 238))                            # '#EE82EE'
    eflatun = convert_color_to_ansi((255, 0, 255))                              # '#FF00FF'
    orta_menekse_kirmizi = convert_color_to_ansi((199, 21, 133))                # '#C71585'
    soluk_menekse_kirmizi = convert_color_to_ansi((219, 112, 147))              # '#DB7093'
    derin_pembe = convert_color_to_ansi((255, 20, 147))                         # '#FF1493'
    sicak_pembe = convert_color_to_ansi((255, 105, 180))                        # '#FF69B4'
    acik_pembe = convert_color_to_ansi((255, 182, 193))                         # '#FFB6C1'
    pembe = convert_color_to_ansi((255, 192, 203))                              # '#FFC0CB'
    antik_beyaz = convert_color_to_ansi((250, 235, 215))                        # '#FAEBD7'
    bej = convert_color_to_ansi((245, 245, 220))                                # '#F5F5DC'
    bisque = convert_color_to_ansi((255, 228, 196))                             # '#FFE4C4'
    beyazlatilmis_badem = convert_color_to_ansi((255, 235, 205))                # '#FFEBCD'
    bugday = convert_color_to_ansi((245, 222, 179))                             # '#F5DEB3'
    misir_puskulu = convert_color_to_ansi((255, 248, 220))                      # '#FFF8DC'
    limonlu_sifon = convert_color_to_ansi((255, 250, 205))                      # '#FFFACD'
    acik_altin_cubuk_sarisi = convert_color_to_ansi((250, 250, 210))            # '#FAFAD2'
    acik_sari = convert_color_to_ansi((255, 255, 224))                          # '#FFFFE0'
    eyer_kahverengi = convert_color_to_ansi((139, 69, 19))                      # '#8B4513'
    sienna = convert_color_to_ansi((160, 82, 45))                               # '#A0522D'
    cikolata = convert_color_to_ansi((210, 105, 30))                            # '#D2691E'
    peru = convert_color_to_ansi((205, 133, 63))                                # '#CD853F'
    kumlu_kahverengi = convert_color_to_ansi((244, 164, 96))                    # '#F4A460'
    iri_odun = convert_color_to_ansi((222, 184, 135))                           # '#DEB887'
    bronzluk = convert_color_to_ansi((210, 180, 140))                           # '#D2B48C'
    pembe_kahverengi = convert_color_to_ansi((188, 143, 143))                   # '#BC8F8F'
    mokasen = convert_color_to_ansi((255, 228, 181))                            # '#FFE4B5'
    navajo_beyazi = convert_color_to_ansi((255, 222, 173))                      # '#FFDEAD'
    seftali_pufu = convert_color_to_ansi((255, 218, 185))                       # '#FFDAB9'
    puslu_gul = convert_color_to_ansi((255, 228, 225))                          # '#FFE4E1'
    lavanta_allik = convert_color_to_ansi((255, 240, 245))                      # '#FFF0F5'
    keten = convert_color_to_ansi((250, 240, 230))                              # '#FAF0E6'
    eski_dantel = convert_color_to_ansi((253, 245, 230))                        # '#FDF5E6'
    papaya_kirbaci = convert_color_to_ansi((255, 239, 213))                     # '#FFEFD5'
    deniz_kabugu = convert_color_to_ansi((255, 245, 238))                       # '#FFF5EE'
    nane_kremasi = convert_color_to_ansi((245, 255, 250))                       # '#F5FFFA'
    barut_grisi = convert_color_to_ansi((112, 128, 144))                        # '#708090'
    acik_barut_grisi = convert_color_to_ansi((119, 136, 153))                   # '#778899'
    acik_celik_mavisi = convert_color_to_ansi((176, 196, 222))                  # '#B0C4DE'
    lavanta = convert_color_to_ansi((230, 230, 250))                            # '#E6E6FA'
    cicek_beyazi = convert_color_to_ansi((255, 250, 240))                       # '#FFFAF0'
    alice_mavi = convert_color_to_ansi((240, 248, 255))                         # '#F0F8FF'
    hayalet_beyaz = convert_color_to_ansi((248, 248, 255))                      # '#F8F8FF'
    seker_kavunu = convert_color_to_ansi((240, 255, 240))                       # '#F0FFF0'
    fildisi = convert_color_to_ansi((255, 255, 240))                            # '#FFFFF0'
    gok_mavisi = convert_color_to_ansi((240, 255, 255))                         # '#F0FFFF'
    kar = convert_color_to_ansi((255, 250, 250))                                # '#FFFAFA'
    siyah = convert_color_to_ansi((0, 0, 0))                                    # '#000000'
    soluk_gri = convert_color_to_ansi((105, 105, 105))                          # '#696969'
    gri = convert_color_to_ansi((128, 128, 128))                                # '#808080'
    koyu_gri = convert_color_to_ansi((169, 169, 169))                           # '#A9A9A9'
    gumus = convert_color_to_ansi((192, 192, 192))                              # '#C0C0C0'
    acik_gri = convert_color_to_ansi((211, 211, 211))                           # '#D3D3D3'
    gainsboro = convert_color_to_ansi((220, 220, 220))                          # '#DCDCDC'
    beyaz_duman = convert_color_to_ansi((245, 245, 245))                        # '#F5F5F5'
    beyaz = convert_color_to_ansi((255, 255, 255))                              # '#FFFFFF'
